:github_url: https://github.com/j-bac/elpigraph-python/tree/master/elpigraph-python/elpigraph/_AlterStructure.py#L321-L631



elpigraph.CollapseBranches
==========================

.. currentmodule:: elpigraph

.. autofunction:: CollapseBranches